@@ -1,6 +1,21 @@
 #ifndef EPIWORLD_MODEL_MEAT_HPP
 #define EPIWORLD_MODEL_MEAT_HPP
 
+#include <vector>
+#include <functional>
+#include <memory>
+#include <random>
+#include <string>
+#include <map>
+#include <unordered_map>
+#include "config.hpp"
+#include "userdata-bones.hpp"
+#include "adjlist-bones.hpp"
+#include "model-bones.hpp"
+#include "entities-bones.hpp"
+#include "virus-bones.hpp"
+#include "agent-bones.hpp"
+
 /**
  * @brief Function factory for saving model runs
  * 
@@ -184,15 +199,15 @@ inline void Model<TSeq>::events_add(
 
         Event<TSeq> & A = events.at(nactions - 1u);
 
-        A.agent      = agent_;
-        A.virus      = virus_;
-        A.tool       = tool_;
-        A.entity     = entity_;
-        A.new_state  = new_state_;
-        A.queue      = queue_;
-        A.call       = call_;
-        A.idx_agent  = idx_agent_;
-        A.idx_object = idx_object_;
+        A.agent      = std::move(agent_);
+        A.virus      = std::move(virus_);
+        A.tool       = std::move(tool_);
+        A.entity     = std::move(entity_);
+        A.new_state  = std::move(new_state_);
+        A.queue      = std::move(queue_);
+        A.call       = std::move(call_);
+        A.idx_agent  = std::move(idx_agent_);
+        A.idx_object = std::move(idx_object_);
 
     }
 
@@ -213,36 +228,47 @@ inline void Model<TSeq>::events_run()
 
         #ifdef EPI_DEBUG
         if (a.new_state >= static_cast<epiworld_fast_int>(nstates))
+        {
             throw std::range_error(
                 "The proposed state " + std::to_string(a.new_state) + " is out of range. " +
                 "The model currently has " + std::to_string(nstates - 1) + " states.");
 
-        if (a.new_state < 0)
+        }
+        else if ((a.new_state != -99) && (a.new_state < 0))
+        {
             throw std::range_error(
                 "The proposed state " + std::to_string(a.new_state) + " is out of range. " +
                 "The state cannot be negative.");
+        }
         #endif
 
         // Undoing the change in the transition matrix
-        if ((p->state_last_changed == today()) && (static_cast<int>(p->state) != a.new_state))
+        if (
+            (a.new_state != -99) &&
+            (p->state_last_changed == today()) &&
+            (static_cast<int>(p->state) != a.new_state)
+        )
         {
             // Undoing state change in the transition matrix
             // The previous state is already recorded
             db.update_state(p->state_prev, p->state, true);
 
-        } else 
+        } else if (p->state_last_changed != today()) 
             p->state_prev = p->state; // Recording the previous state
 
         // Applying function after the fact. This way, if there were
         // updates, they can be recorded properly, before losing the information
-        p->state = a.new_state;
         if (a.call)
         {
             a.call(a, this);
         }
 
+        if (a.new_state != -99)
+            p->state = a.new_state;
+
         // Registering that the last change was today
         p->state_last_changed = today();
+        
 
         #ifdef EPI_DEBUG
         if (static_cast<int>(p->state) >= static_cast<int>(nstates))
@@ -252,7 +278,7 @@ inline void Model<TSeq>::events_run()
         #endif
 
         // Updating queue
-        if (use_queuing)
+        if (use_queuing && a.queue != -99)
         {
 
             if (a.queue == Queue<TSeq>::Everyone)
@@ -837,11 +863,12 @@ inline epiworld_double Model<TSeq>::rgamma() {
 
 template<typename TSeq>
 inline epiworld_double Model<TSeq>::rgamma(epiworld_double alpha, epiworld_double beta) {
-    auto old_param = rgammad.param();
-    rgammad.param(std::gamma_distribution<>::param_type(alpha, beta));
-    epiworld_double ans = rgammad(*engine);
-    rgammad.param(old_param);
-    return ans;
+
+    return rgammad(
+        *engine,
+        std::gamma_distribution<>::param_type(alpha, beta)
+    );
+    
 }
 
 template<typename TSeq>
@@ -851,11 +878,12 @@ inline epiworld_double Model<TSeq>::rexp() {
 
 template<typename TSeq>
 inline epiworld_double Model<TSeq>::rexp(epiworld_double lambda) {
-    auto old_param = rexpd.param();
-    rexpd.param(std::exponential_distribution<>::param_type(lambda));
-    epiworld_double ans = rexpd(*engine);
-    rexpd.param(old_param);
-    return ans;
+
+    return rexpd(
+        *engine,
+        std::exponential_distribution<>::param_type(lambda)
+    );
+
 }
 
 template<typename TSeq>
@@ -865,11 +893,11 @@ inline epiworld_double Model<TSeq>::rlognormal() {
 
 template<typename TSeq>
 inline epiworld_double Model<TSeq>::rlognormal(epiworld_double mean, epiworld_double shape) {
-    auto old_param = rlognormald.param();
-    rlognormald.param(std::lognormal_distribution<>::param_type(mean, shape));
-    epiworld_double ans = rlognormald(*engine);
-    rlognormald.param(old_param);
-    return ans;
+    
+    return rlognormald(
+        *engine,
+        std::lognormal_distribution<>::param_type(mean, shape)
+    );
 }
 
 template<typename TSeq>
@@ -879,11 +907,15 @@ inline int Model<TSeq>::rbinom() {
 
 template<typename TSeq>
 inline int Model<TSeq>::rbinom(int n, epiworld_double p) {
-    auto old_param = rbinomd.param();
-    rbinomd.param(std::binomial_distribution<>::param_type(n, p));
-    epiworld_double ans = rbinomd(*engine);
-    rbinomd.param(old_param);
-    return ans;
+
+    if (n == 0 || p == 0.0)
+        return 0;
+
+    return rbinomd(
+        *engine,
+        std::binomial_distribution<>::param_type(n, p)
+    );
+
 }
 
 template<typename TSeq>
@@ -893,11 +925,11 @@ inline int Model<TSeq>::rnbinom() {
 
 template<typename TSeq>
 inline int Model<TSeq>::rnbinom(int n, epiworld_double p) {
-    auto old_param = rnbinomd.param();
-    rnbinomd.param(std::negative_binomial_distribution<>::param_type(n, p));
-    int ans = rnbinomd(*engine);
-    rnbinomd.param(old_param);
-    return ans;
+
+    return rnbinomd(
+        *engine,
+        std::negative_binomial_distribution<>::param_type(n, p)
+    );
 }
 
 template<typename TSeq>
@@ -907,11 +939,12 @@ inline int Model<TSeq>::rgeom() {
 
 template<typename TSeq>
 inline int Model<TSeq>::rgeom(epiworld_double p) {
-    auto old_param = rgeomd.param();
-    rgeomd.param(std::geometric_distribution<>::param_type(p));
-    int ans = rgeomd(*engine);
-    rgeomd.param(old_param);
-    return ans;
+
+    return rgeomd(
+        *engine,
+        std::geometric_distribution<>::param_type(p)
+    );
+
 }
 
 template<typename TSeq>
@@ -921,11 +954,12 @@ inline int Model<TSeq>::rpoiss() {
 
 template<typename TSeq>
 inline int Model<TSeq>::rpoiss(epiworld_double lambda) {
-    auto old_param = rpoissd.param();
-    rpoissd.param(std::poisson_distribution<>::param_type(lambda));
-    int ans = rpoissd(*engine);
-    rpoissd.param(old_param);
-    return ans;
+    
+    return rpoissd(
+        *engine,
+        std::poisson_distribution<>::param_type(lambda)
+    );
+
 }
 
 template<typename TSeq>
@@ -1290,6 +1324,34 @@ inline int Model<TSeq>::today() const {
 template<typename TSeq>
 inline void Model<TSeq>::next() {
 
+    #ifdef EPI_DEBUG
+    // Checking all the agents have proper states
+    for (auto & p : population)
+    {
+        if ((p.state >= nstates) || (p.state < 0))
+        {
+            throw std::range_error(
+                "The agent " + std::to_string(p.id) +
+                " has state " + std::to_string(p.state) +
+                " which is above the maximum state of " +
+                std::to_string(nstates - 1) + "."
+            );
+        }
+
+        if ((p.state_prev >= nstates) || (p.state_prev < 0))
+        {
+            throw std::range_error(
+                "The agent " + std::to_string(p.id) +
+                " has previous state " + std::to_string(p.state_prev) +
+                " which is above the maximum state of " +
+                std::to_string(nstates - 1) + "."
+            );
+        }
+        
+    }
+
+    #endif
+
     db.record();
     ++this->current_date;
     
@@ -1442,7 +1504,10 @@ inline void Model<TSeq>::run_multiple(
     }
     // #endif
 
-    EPI_DEBUG_NOTIFY_ACTIVE()
+    if (verbose)
+    {
+        EPI_DEBUG_NOTIFY_ACTIVE()
+    }
 
     bool old_verb = this->verbose;
     verbose_off();
@@ -1476,26 +1541,24 @@ inline void Model<TSeq>::run_multiple(
     }
         
 
-    // Figuring out how many replicates
+    // Figuring out how many replicates - distribute remainder evenly
     std::vector< size_t > nreplicates(nthreads, 0);
     std::vector< size_t > nreplicates_csum(nthreads, 0);
+    
+    size_t base_replicates = nexperiments / nthreads;
+    size_t remainder = nexperiments % nthreads;
+    
     size_t sums = 0u;
     for (int i = 0; i < nthreads; ++i)
     {
-        nreplicates[i] = static_cast<epiworld_fast_uint>(
-            std::floor(nexperiments/nthreads)
-            );
+        // Distribute remainder to first 'remainder' threads
+        nreplicates[i] = base_replicates + (static_cast<size_t>(i) < remainder ? 1 : 0);
         
         // This takes the cumsum
         nreplicates_csum[i] = sums;
-
         sums += nreplicates[i];
-
     }
 
-    if (sums < nexperiments)
-        nreplicates[nthreads - 1] += (nexperiments - sums);
-
     Progress pb_multiple(
         nreplicates[0u],
         EPIWORLD_PROGRESS_BAR_WIDTH
@@ -1553,7 +1616,7 @@ inline void Model<TSeq>::run_multiple(
 
                 // Only the first one prints
                 if (verbose)
-                    pb_multiple.next();                
+                    pb_multiple.next();
 
             } else {
 
@@ -1565,8 +1628,6 @@ inline void Model<TSeq>::run_multiple(
 
             }
 
-            
-
         }
         
     }
@@ -1618,9 +1679,6 @@ inline void Model<TSeq>::run_multiple(
     }
     #endif
 
-    if (verbose)
-        pb_multiple.end();
-
     if (old_verb)
         verbose_on();
 
@@ -1721,6 +1779,11 @@ inline epiworld_fast_uint Model<TSeq>::get_n_replicates() const
     return n_replicates;
 }
 
+template<typename TSeq>
+inline size_t Model<TSeq>::get_n_entities() const {
+    return entities.size();
+}
+
 template<typename TSeq>
 inline void Model<TSeq>::set_ndays(epiworld_fast_uint ndays) {
     this->ndays = ndays;
@@ -2005,6 +2068,12 @@ Model<TSeq>::get_states() const
     return states_labels;
 }
 
+template<typename TSeq>
+inline size_t Model<TSeq>::get_n_states() const
+{
+    return nstates;
+}
+
 template<typename TSeq>
 inline const std::vector< UpdateFun<TSeq> > &
 Model<TSeq>::get_state_fun() const
@@ -2582,6 +2651,7 @@ inline bool Model<TSeq>::operator==(const Model<TSeq> & other) const
 
 template<typename TSeq>
 inline void Model<TSeq>::draw(
+    DiagramType diagram_type,
     const std::string & fn_output,
     bool self
 ) {
@@ -2589,8 +2659,9 @@ inline void Model<TSeq>::draw(
     ModelDiagram diagram;
 
     diagram.draw_from_data(
+        diagram_type,
         this->get_states(),
-        this->get_db().transition_probability(false),
+        this->get_db().get_transition_probability(false),
         fn_output,
         self
     );
