@@ -1,28 +1,5 @@
 # Test just this file: tinytest::run_test_file("inst/tinytest/test-sirconn.R")
 
-# Function to test transition probability matrix ------------------------
-test_tmat <- function(tmat) {
-  tmat_expected <- structure(
-    c(
-      0.823433858323328, 0, 0, 
-      0.176566141676672, 0.856971222609989, 0, 
-      0, 0.143028777390011, 1
-    ),
-    dim = c(3L, 3L),
-    dimnames = list(
-      c("Susceptible", "Infected", "Recovered"),
-      c("Susceptible", "Infected", "Recovered")
-    )
-  )
-  
-  # Check matches expected output
-  expect_equal(tmat, tmat_expected, tolerance = 0.1)
-  
-  # Check for out of bounds values
-  expect_false(any(tmat < 0))
-  expect_false(any(tmat > 1))
-}
-
 # Create SIR CONN Model --------------------------------------------------------
 expect_silent(sirconn_0 <- ModelSIRCONN(
   name = "A Virus",
@@ -48,7 +25,7 @@ expect_silent(plot(sirconn_0)) # Plot succeeds after model is run
 hist_queuing <- get_hist_total(sirconn_0)
 tmat_queuing <- get_transition_probability(sirconn_0)
 
-test_tmat(tmat_queuing)
+test_tmat_matches_expected(tmat_queuing)
 
 # Check model run without queuing ----------------------------------------------
 expect_warning(queuing_off(sirconn_0), "SIR Connected models do not have queue.")
@@ -68,13 +45,10 @@ good_contact_rate <- 4.0
 good_transmission_rate <- 0.5
 good_recovery_rate <- 1.0/7.0
 
-bad_name <- NA
-bad_n <- NA
-bad_prevalence <- NA
-bad_contact_rate <- NA
-bad_transmission_rate <- NA
-bad_recovery_rate <- NA
+bad_name <- 10
+bad_numeric_input <- "not a number"
 
+expected_error_msg_na <- "must not be NA"
 expected_error_msg_str <- "must be a string"
 expected_error_msg_int <- "must be an integer"
 expected_error_msg_double <- "must be a double"
@@ -90,7 +64,7 @@ expect_error(sirconn_0 <- ModelSIRCONN(
 
 expect_error(sirconn_0 <- ModelSIRCONN(
   name = good_name,
-  n = bad_n,
+  n = bad_numeric_input,
   prevalence = good_prevalence,
   contact_rate = good_contact_rate,
   transmission_rate = good_transmission_rate,
@@ -100,7 +74,7 @@ expect_error(sirconn_0 <- ModelSIRCONN(
 expect_error(sirconn_0 <- ModelSIRCONN(
   name = good_name,
   n = good_n,
-  prevalence = bad_prevalence,
+  prevalence = bad_numeric_input,
   contact_rate = good_contact_rate,
   transmission_rate = good_transmission_rate,
   recovery_rate = good_recovery_rate
@@ -110,7 +84,7 @@ expect_error(sirconn_0 <- ModelSIRCONN(
   name = good_name,
   n = good_n,
   prevalence = good_prevalence,
-  contact_rate = bad_contact_rate,
+  contact_rate = bad_numeric_input,
   transmission_rate = good_transmission_rate,
   recovery_rate = good_recovery_rate
 ), expected_error_msg_double)
@@ -120,7 +94,7 @@ expect_error(sirconn_0 <- ModelSIRCONN(
   n = good_n,
   prevalence = good_prevalence,
   contact_rate = good_contact_rate,
-  transmission_rate = bad_transmission_rate,
+  transmission_rate = bad_numeric_input,
   recovery_rate = good_recovery_rate
 ), expected_error_msg_double)
 
@@ -130,6 +104,6 @@ expect_error(sirconn_0 <- ModelSIRCONN(
   prevalence = good_prevalence,
   contact_rate = good_contact_rate,
   transmission_rate = good_transmission_rate,
-  recovery_rate = bad_recovery_rate
+  recovery_rate = bad_numeric_input
 ), expected_error_msg_double)
 
